/*
Copyright 2020 Adobe. All rights reserved.
This file is licensed to you under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License. You may obtain a copy
of the License at http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under
the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR REPRESENTATIONS
OF ANY KIND, either express or implied. See the License for the specific language
governing permissions and limitations under the License.
*/
import { __decorate } from "tslib";
import { html, property, LitElement, } from 'lit-element';
import { FocusVisiblePolyfillMixin } from '@spectrum-web-components/shared/lib/focus-visible.js';
import tabItemStyles from './tab.css.js';
/**
 * @slot icon - The icon that appears on the left of the label
 */
let Tab = /** @class */ (() => {
    class Tab extends FocusVisiblePolyfillMixin(LitElement) {
        constructor() {
            super(...arguments);
            this.label = '';
            this.selected = false;
            this.vertical = false;
            this.value = '';
        }
        static get styles() {
            return [tabItemStyles];
        }
        get hasIcon() {
            return !!this.querySelector('[slot="icon"]');
        }
        render() {
            return html `
            ${this.hasIcon
                ? html `
                      <slot name="icon"></slot>
                  `
                : html ``}
            ${this.label
                ? html `
                      <label id="itemLabel">
                          ${this.label}
                      </label>
                  `
                : html ``}
        `;
        }
        firstUpdated() {
            this.setAttribute('role', 'tab');
        }
        updated(changes) {
            if (changes.has('selected')) {
                this.setAttribute('aria-selected', this.selected ? 'true' : 'false');
                this.setAttribute('tabindex', this.selected ? '0' : '-1');
            }
        }
    }
    __decorate([
        property({ reflect: true })
    ], Tab.prototype, "label", void 0);
    __decorate([
        property({ type: Boolean, reflect: true })
    ], Tab.prototype, "selected", void 0);
    __decorate([
        property({ type: Boolean, reflect: true })
    ], Tab.prototype, "vertical", void 0);
    __decorate([
        property({ type: String, reflect: true })
    ], Tab.prototype, "value", void 0);
    return Tab;
})();
export { Tab };
//# sourceMappingURL=tab.js.map